<?php

namespace Drupal\cloudflare_sitemap\Commands;

use Consolidation\SiteAlias\SiteAliasManagerAwareTrait;
use Drupal\cloudflare_sitemap\CachePurger;
use Drush\Commands\DrushCommands;
use Drush\SiteAlias\SiteAliasManagerAwareInterface;
use Drupal\Core\Url;

/**
 * CacheCommands class.
 */
class CachePurgerCommands extends DrushCommands implements SiteAliasManagerAwareInterface {

  use SiteAliasManagerAwareTrait;

  /**
   * Cloudflare cache purger service.
   *
   * @var \Drupal\cloudflare_sitemap\CachePurger
   */
  protected $cachePurger;

  /**
   * CacheCommands constructor.
   *
   * @param \Drupal\cloudflare_sitemap\CachePurger $cache_purger
   *   Cloudflare cache purger service.
   */
  public function __construct(CachePurger $cache_purger) {
    parent::__construct();
    $this->cachePurger = $cache_purger;
  }

  /**
   * Purge sitemap URLs from Cloudflare CDN cache.
   *
   * @param string $url
   *   The URL to the sitemap.
   *
   * @command cloudflare-purge-sitemap
   * @aliases cfps
   *
   * @return bool
   *   TRUE on success.
   */
  public function purgeSitemap($url = null) {
    $url = $url ?? Url::fromRoute('simple_sitemap.sitemap_default', null, ['absolute' => TRUE])->toString();

    // Flush CDN cache for the website via sitemap.
    $this->cachePurger->purgeSitemap($url);

    return TRUE;
  }

}
